@@ -27,6 +27,7 @@
 #include <unistd.h>
 #include <stdlib.h>
 #include <glib/gi18n.h>
+#include <handy.h>
 
 #ifdef HAVE_CHEESE
 #include <cheese-gtk.h>
@@ -38,6 +39,7 @@
 #include "pages/network/gis-network-page.h"
 #include "pages/timezone/gis-timezone-page.h"
 #include "pages/privacy/gis-privacy-page.h"
+#include "pages/software/gis-software-page.h"
 #include "pages/goa/gis-goa-page.h"
 #include "pages/account/gis-account-pages.h"
 #include "pages/parental-controls/gis-parental-controls-page.h"
@@ -48,7 +50,6 @@
 #define VENDOR_SKIP_KEY "skip"
 #define VENDOR_NEW_USER_ONLY_KEY "new_user_only"
 #define VENDOR_EXISTING_USER_ONLY_KEY "existing_user_only"
-#define VENDOR_RUN_WELCOME_TOUR_KEY "run_welcome_tour"
 
 static gboolean force_existing_user_mode;
 
@@ -71,6 +72,7 @@ static PageData page_table[] = {
   PAGE (network,  FALSE),
   PAGE (privacy,  FALSE),
   PAGE (timezone, TRUE),
+  PAGE (software, TRUE),
   PAGE (goa,      FALSE),
   PAGE (account,  TRUE),
   PAGE (password, TRUE),
@@ -288,6 +290,9 @@ main (int argc, char *argv[])
 #endif
 
   gtk_init (&argc, &argv);
+  hdy_init ();
+  hdy_style_manager_set_color_scheme (hdy_style_manager_get_default (),
+    HDY_COLOR_SCHEME_PREFER_LIGHT);
 
   g_message ("Starting gnome-initial-setup");
   if (gis_get_mock_mode ())
@@ -308,6 +313,20 @@ main (int argc, char *argv[])
 
   driver = gis_driver_new (mode);
 
+  /* On first login, GNOME Shell offers to run a tour. If we also run Initial
+   * Setup, the two immovable, centred windows will sit atop one another.
+   * Until we have the ability to run Initial Setup in the "kiosk" mode, like
+   * it does in new-user mode, disable Initial Setup for existing users.
+   *
+   * https://gitlab.gnome.org/GNOME/gnome-initial-setup/-/issues/120#note_1019004
+   * https://gitlab.gnome.org/GNOME/gnome-initial-setup/-/issues/12
+   */
+  if (mode == GIS_DRIVER_MODE_EXISTING_USER) {
+    g_message ("Skipping gnome-initial-setup for existing user");
+    gis_ensure_stamp_files (driver);
+    exit (EXIT_SUCCESS);
+  }
+
   /* We only do this in existing-user mode, because if gdm launches us
    * in new-user mode and we just exit, gdm's special g-i-s session
    * never terminates. */
@@ -334,17 +353,6 @@ gis_ensure_stamp_files (GisDriver *driver)
   g_autofree gchar *done_file = NULL;
   g_autoptr(GError) error = NULL;
 
-  if (gis_driver_conf_get_boolean (driver,
-                                   VENDOR_PAGES_GROUP,
-                                   VENDOR_RUN_WELCOME_TOUR_KEY,
-                                   TRUE)) {
-      welcome_file = g_build_filename (g_get_user_config_dir (), "run-welcome-tour", NULL);
-      if (!g_file_set_contents (welcome_file, "yes", -1, &error)) {
-          g_warning ("Unable to create %s: %s", welcome_file, error->message);
-          g_clear_error (&error);
-      }
-  }
-
   done_file = g_build_filename (g_get_user_config_dir (), "gnome-initial-setup-done", NULL);
   if (!g_file_set_contents (done_file, "yes", -1, &error)) {
       g_warning ("Unable to create %s: %s", done_file, error->message);
